"use strict";
/*
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DataSetUtils = void 0;
const fs = require("fs");
const imperative_1 = require("@zowe/imperative");
const CoreUtils_1 = require("./CoreUtils");
const DataSetInterface_1 = require("./DataSetInterface");
const StreamUtils_1 = require("./StreamUtils");
class DataSetUtils {
    /**
     * Lists datasets with the specified dataset name pattern.
     *
     * @param connection - zos-node-accessor connection
     * @param pattern - dataset name pattern
     * @returns dataset entries
     */
    static listDataSets(connection, pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Listing data sets matching pattern '%s' via FTP", pattern);
            const files = yield connection.listDataset(pattern);
            this.log.debug("Found %d matching data sets", files.length);
            const filteredFiles = files.map((file) => CoreUtils_1.CoreUtils.addLowerCaseKeysToObject(file));
            return filteredFiles;
        });
    }
    /**
     * Lists members of PDS dataset of the specified dataset name.
     *
     * @param connection - zos-node-accessor connection
     * @param dsn - fully-qualified dataset name without quotes
     * @returns member entries
     */
    static listMembers(connection, dsn) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("List members of %s", dsn);
            const datasetname = dsn + "(*)";
            const members = yield connection.listDataset(datasetname);
            this.log.debug("Found %d members", members.length);
            const filteredMembers = members.map((file) => CoreUtils_1.CoreUtils.addLowerCaseKeysToObject(file));
            return filteredMembers;
        });
    }
    /**
     * Delets the dataset of the specified dataset name.
     *
     * @param connection - zos-node-accessor connection
     * @param dsn - fully-qualified dataset name without quotes
     */
    static deleteDataSet(connection, dsn) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Deleting data set '%s'", dsn);
            yield connection.deleteDataset("'" + dsn + "'");
        });
    }
    /**
     * Renames the dataset.
     *
     * @param connection - zos-node-accessor connection
     * @param oldDsn - old fully-qualified dataset name without quotes
     * @param newDsn - new fully-qualified dataset name without quotes
     */
    static renameDataSet(connection, oldDsn, newDsn) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Attempting to rename data set from '%s' to '%s'", oldDsn, newDsn);
            yield connection.rename(oldDsn, newDsn);
        });
    }
    /**
     * Downloads the dataset. The contents will saved in local file, if localFile is provided in option. Otherwise, the contents
     * will be returned in Buffer.
     *
     * @param connection - zos-node-accessor connection
     * @param dsn - fully-qualified dataset name without quotes
     * @param option - download option
     * @returns dataset contents in Buffer, if localFile is not provided in option. Otherwise, undefined will be returned.
     */
    static downloadDataSet(connection, dsn, option) {
        return __awaiter(this, void 0, void 0, function* () {
            const files = yield connection.listDataset(dsn);
            if (files === undefined || files.length === 0) {
                throw new Error(`The dataset "${dsn}" doesn't exist.`);
            }
            const estimatedSize = parseInt(files[0].Used, 10) * DataSetInterface_1.TRACK;
            const transferType = option.transferType || CoreUtils_1.TRANSFER_TYPE_ASCII;
            let buffer;
            let length;
            const stream = yield connection.getDataset(dsn, transferType, true);
            if (option.localFile) {
                this.log.debug("Downloading data set '%s' to local file '%s' in transfer mode '%s", dsn, option.localFile, transferType);
                imperative_1.IO.createDirsSyncFromFilePath(option.localFile);
                const writable = fs.createWriteStream(option.localFile);
                length = yield StreamUtils_1.StreamUtils.streamToStream(estimatedSize, stream, writable, option.progress);
            }
            else {
                this.log.debug("Downloading data set '%s' in transfer mode '%s'", dsn, transferType);
                buffer = yield StreamUtils_1.StreamUtils.streamToBuffer(estimatedSize, stream, option.progress);
                length = buffer.byteLength;
            }
            this.log.info("Successfully downloaded %d bytes of content from %s", length, dsn);
            return Promise.resolve(buffer);
        });
    }
    /**
     * Uploads the content to the specified dataset.
     *
     * @param connection - zos-node-accessor connection
     * @param dsn - fully-qualified dataset name without quotes
     * @param option - upload option
     */
    static uploadDataSet(connection, dsn, option) {
        return __awaiter(this, void 0, void 0, function* () {
            const transferType = option.transferType || CoreUtils_1.TRANSFER_TYPE_ASCII;
            let content = option.content;
            if (option.localFile) {
                this.log.debug("Attempting to upload from local file '%s' to data set '%s' in transfer mode '%s'", option.localFile, dsn, transferType);
                content = imperative_1.IO.readFileSync(option.localFile, undefined, transferType === CoreUtils_1.TRANSFER_TYPE_BINARY);
            }
            else {
                this.log.debug("Attempting to upload to data set '%s' in transfer mode '%s'", dsn, option.transferType);
            }
            if (transferType === CoreUtils_1.TRANSFER_TYPE_ASCII) {
                content = CoreUtils_1.CoreUtils.addCarriageReturns(content.toString());
            }
            yield connection.uploadDataset(content, "'" + dsn + "'", transferType, option.dcb);
        });
    }
    /**
     * Allocate dataset.
     *
     * @param connection - zos-node-accessor connection
     * @param dsn - fully-qualified dataset name without quotes
     * @param option - Allocate option
     */
    static allocateDataSet(connection, dsn, option) {
        return __awaiter(this, void 0, void 0, function* () {
            this.log.debug("Allocate data set '%s'", dsn);
            yield connection.allocateDataset(dsn, option.dcb);
        });
    }
    static get log() {
        return imperative_1.Logger.getAppLogger();
    }
}
exports.DataSetUtils = DataSetUtils;
//# sourceMappingURL=DataSetUtils.js.map